export { demoFrameParms } from "./DemoParms.js";
export declare const enum GlottalSourceType {
    impulsive = 0,
    natural = 1,
    noise = 2
}
export declare const glottalSourceTypeEnumNames: string[];
export declare const maxOralFormants = 6;
export interface MainParms {
    sampleRate: number;
    glottalSourceType: GlottalSourceType;
}
export interface FrameParms {
    duration: number;
    f0: number;
    flutterLevel: number;
    openPhaseRatio: number;
    breathinessDb: number;
    tiltDb: number;
    gainDb: number;
    agcRmsLevel: number;
    nasalFormantFreq: number;
    nasalFormantBw: number;
    oralFormantFreq: number[];
    oralFormantBw: number[];
    cascadeEnabled: boolean;
    cascadeVoicingDb: number;
    cascadeAspirationDb: number;
    cascadeAspirationMod: number;
    nasalAntiformantFreq: number;
    nasalAntiformantBw: number;
    parallelEnabled: boolean;
    parallelVoicingDb: number;
    parallelAspirationDb: number;
    parallelAspirationMod: number;
    fricationDb: number;
    fricationMod: number;
    parallelBypassDb: number;
    nasalFormantDb: number;
    oralFormantDb: number[];
}
export declare class Generator {
    private mParms;
    private fParms;
    private newFParms;
    private fState;
    private pState;
    private absPosition;
    private tiltFilter;
    private outputLpFilter;
    private flutterTimeOffset;
    private impulsiveGSource;
    private naturalGSource;
    private glottalSource;
    private aspirationSourceCasc;
    private aspirationSourcePar;
    private fricationSourcePar;
    private nasalFormantCasc;
    private nasalAntiformantCasc;
    private oralFormantCasc;
    private nasalFormantPar;
    private oralFormantPar;
    private differencingFilterPar;
    constructor(mParms: MainParms);
    generateFrame(fParms: FrameParms, outBuf: Float64Array): void;
    private computeNextOutputSignalSample;
    private computeCascadeBranch;
    private computeParallelBranch;
    private startNewPeriod;
    private startUsingNewFrameParameters;
    private initGlottalSource;
    private startGlottalSourcePeriod;
}
export declare function generateSound(mParms: MainParms, fParmsA: FrameParms[]): Float64Array;
export declare function getVocalTractTransferFunctionCoefficients(mParms: MainParms, fParms: FrameParms): Float64Array[];
